| rescale_alpha | R Documentation |
Computes the adjusted significance threshold alpha / M used in
the Stack / M correction of Sherlock et al. (2026). Dividing the
nominal alpha by the number of imputations M counteracts the
inflated test statistics that arise from stacking M copies of
the data.
rescale_alpha(alpha = 0.05, m)
alpha |
Numeric. Nominal significance level (default |
m |
A single positive integer. Number of imputations. |
A single numeric value: alpha / m.
Sherlock, P., Mansolf, M., Hofheimer, J., Hockett, C. W., O'Connor, T. G., Roubinov, D., Graff, J. C., Lai, J.-S., Bush, N. R., Wright, R. J., & Chiu, Y.-H. M. (2026). Beyond linear risk: A machine learning approach to understanding perinatal depression in context. Multivariate Behavioral Research, 1–16. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/00273171.2026.2661244")}
ctree_stacked, stack_imputations
rescale_alpha(0.05, 30) # 0.001666...
rescale_alpha(0.05, 10) # 0.005
rescale_alpha(0.01, 5) # 0.002
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.